@@ -7,9 +7,7 @@ use std::{
 };
 
 use slotmap::DenseSlotMap;
-
 use naia_server_socket::{Packet, ServerAddrs, Socket};
-
 pub use naia_shared::{
     wrapping_diff, BaseConnection, ConnectionConfig, Instant, KeyGenerator, LocalComponentKey,
     ManagerType, Manifest, PacketReader, PacketType, PropertyMutate, PropertyMutator,
@@ -132,6 +130,12 @@ impl<P: ProtocolType, E: Copy + Eq + Hash> Server<P, E> {
         );
     }
 
+    /// Returns whether or not the Server has initialized correctly and is
+    /// listening for Clients
+    pub fn is_listening(&self) -> bool {
+        self.io.is_loaded()
+    }
+
     /// Must be called regularly, maintains connection to and receives messages
     /// from all Clients
     pub fn receive(&mut self) -> VecDeque<Result<Event<P, E>, NaiaServerError>> {
